texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[8344] parsetexi update


From: gavinsmith0123
Subject: [8344] parsetexi update
Date: Fri, 19 Oct 2018 16:58:07 -0400 (EDT)

Revision: 8344
          http://svn.sv.gnu.org/viewvc/?view=rev&root=texinfo&revision=8344
Author:   gavin
Date:     2018-10-19 16:58:06 -0400 (Fri, 19 Oct 2018)
Log Message:
-----------
parsetexi update

Modified Paths:
--------------
    trunk/tp/Texinfo/XS/parsetexi/api.c
    trunk/tp/Texinfo/XS/parsetexi/end_line.c
    trunk/tp/Texinfo/XS/parsetexi/extra.c
    trunk/tp/Texinfo/XS/parsetexi/tree.c
    trunk/tp/Texinfo/XS/parsetexi/tree_types.h

Modified: trunk/tp/Texinfo/XS/parsetexi/api.c
===================================================================
--- trunk/tp/Texinfo/XS/parsetexi/api.c 2018-10-19 20:39:09 UTC (rev 8343)
+++ trunk/tp/Texinfo/XS/parsetexi/api.c 2018-10-19 20:58:06 UTC (rev 8344)
@@ -1,5 +1,4 @@
-/* Copyright 2010, 2011, 2012, 2013, 2014, 2015
-   Free Software Foundation, Inc.
+/* Copyright 2010-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -359,7 +358,7 @@
                 element_to_perl_hash (f);
               STORE(newRV_inc ((SV *)f->hv));
               break;
-            case extra_element_contents:
+            case extra_contents:
               {
               int j;
               if (f)
@@ -366,9 +365,9 @@
                 STORE(build_perl_array (&f->contents));
               break;
               }
-            case extra_element_contents_array:
+            case extra_contents_array:
               {
               /* Like extra_element_contents, but this time output an array
                  of arrays (instead of an array). */
               int j, k;
               AV *av;

Modified: trunk/tp/Texinfo/XS/parsetexi/end_line.c
===================================================================
--- trunk/tp/Texinfo/XS/parsetexi/end_line.c    2018-10-19 20:39:09 UTC (rev 
8343)
+++ trunk/tp/Texinfo/XS/parsetexi/end_line.c    2018-10-19 20:58:06 UTC (rev 
8344)
@@ -1052,6 +1052,7 @@
             {
               // Perl code was sceptical whether we could get here,
               // but we got here from t/21multitable.t on 2015.11.30.
+              // FIXME: put an abort() here and run the tests
               if (!e->cmd)
                 {
                   command_warn (current, "unexpected argument on @%s line:",

Modified: trunk/tp/Texinfo/XS/parsetexi/extra.c
===================================================================
--- trunk/tp/Texinfo/XS/parsetexi/extra.c       2018-10-19 20:39:09 UTC (rev 
8343)
+++ trunk/tp/Texinfo/XS/parsetexi/extra.c       2018-10-19 20:58:06 UTC (rev 
8344)
@@ -1,5 +1,4 @@
-/* Copyright 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017
-   Free Software Foundation, Inc.
+/* Copyright 2010-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -66,7 +65,7 @@
 void
 add_extra_contents (ELEMENT *e, char *key, ELEMENT *value)
 {
-  add_extra_key (e, key, value, extra_element_contents);
+  add_extra_key (e, key, value, extra_contents);
 }
 
 /* An array of content arrays. */
@@ -73,7 +72,7 @@
 void
 add_extra_contents_array (ELEMENT *e, char *key, ELEMENT *value)
 {
-  add_extra_key (e, key, value, extra_element_contents_array);
+  add_extra_key (e, key, value, extra_contents_array);
 }
 
 /* Add an extra key that is a reference to the text field of another
@@ -81,7 +80,7 @@
 void
 add_extra_text (ELEMENT *e, char *key, ELEMENT *value)
 {
-  add_extra_key (e, key, value, extra_element_text);
+  add_extra_key (e, key, value, extra_text);
 }
 
 void

Modified: trunk/tp/Texinfo/XS/parsetexi/tree.c
===================================================================
--- trunk/tp/Texinfo/XS/parsetexi/tree.c        2018-10-19 20:39:09 UTC (rev 
8343)
+++ trunk/tp/Texinfo/XS/parsetexi/tree.c        2018-10-19 20:58:06 UTC (rev 
8344)
@@ -1,5 +1,4 @@
-/* Copyright 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
-   Free Software Foundation, Inc.
+/* Copyright 2010-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -67,11 +66,11 @@
         case extra_element_oot:
           destroy_element_and_children (e->extra[i].value);
           break;
-        case extra_element_contents:
+        case extra_contents:
           if (e->extra[i].value)
             destroy_element ((ELEMENT *) e->extra[i].value);
           break;
-        case extra_element_contents_array:
+        case extra_contents_array:
           {
             int j;
             ELEMENT *array = e->extra[i].value;

Modified: trunk/tp/Texinfo/XS/parsetexi/tree_types.h
===================================================================
--- trunk/tp/Texinfo/XS/parsetexi/tree_types.h  2018-10-19 20:39:09 UTC (rev 
8343)
+++ trunk/tp/Texinfo/XS/parsetexi/tree_types.h  2018-10-19 20:58:06 UTC (rev 
8344)
@@ -1,5 +1,4 @@
-/* Copyright 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
-   Free Software Foundation, Inc.
+/* Copyright 2010-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,9 +27,9 @@
 enum extra_type {
     extra_element,
     extra_element_oot,
-    extra_element_contents,
-    extra_element_contents_array,
-    extra_element_text,
+    extra_contents,
+    extra_contents_array,
+    extra_text,
     extra_index_entry,
     extra_misc_args,
     extra_node_spec,
@@ -366,9 +365,9 @@
               {
-              /* Like extra_element_contents, but this time output an array
+              /* Like extra_contents, but this time output an array
                  of arrays (instead of an array). */
               int j, k;




reply via email to

[Prev in Thread] Current Thread [Next in Thread]